@@ -1,5 +1,6 @@
 
 from cloud_governance.common.logger.init_logger import logger
+from cloud_governance.common.logger.logger_time_stamp import logger_time_stamp
 from cloud_governance.ibm.tagging.tagging_operations import TaggingOperations
 
 
@@ -18,7 +19,9 @@ class TagBareMetal(TaggingOperations):
         @return:
         """
         hardware_data = self._classic_operations.get_hardware_data(hardware_id=str(hardware_id))
-        return hardware_data.get('billingItem').get('orderItem').get('order').get('userRecord').get('username'), f'{hardware_data.get("hostname")}.{hardware_data.get("domain")}'
+        if hardware_data:
+            return hardware_data.get('billingItem').get('orderItem').get('order').get('userRecord').get('username'), f'{hardware_data.get("hostname")}.{hardware_data.get("domain")}'
+        return '', ''
 
     def tag_remove_hardware(self, user_tags: list, hardware_tags: list, hardware_id: str, hardware_name: str):
         """
@@ -77,14 +80,17 @@ class TagBareMetal(TaggingOperations):
         @return:
         """
         username, hardware_name = self.get_hardware_username(hardware_id=hardware_id)
-        hardware_tags = self._classic_operations.get_hardware_tags(hardware_id=str(hardware_id))
-        user_tags = self._ibm_client.get_user_tags_from_gsheet(username=username)
-        if self._tag_operation == 'remove':
-            tags = self.tag_remove_hardware(user_tags, hardware_tags, hardware_id, hardware_name)
-        else:
-            tags = self.tag_update_hardware(user_tags, hardware_tags, hardware_id, hardware_name)
-        return tags
+        if username and hardware_name:
+            hardware_tags = self._classic_operations.get_hardware_tags(hardware_id=str(hardware_id))
+            user_tags = self._ibm_client.get_user_tags_from_gsheet(username=username)
+            if self._tag_operation == 'remove':
+                tags = self.tag_remove_hardware(user_tags, hardware_tags, hardware_id, hardware_name)
+            else:
+                tags = self.tag_update_hardware(user_tags, hardware_tags, hardware_id, hardware_name)
+            return tags
+        return []
 
+    @logger_time_stamp
     def run(self, hardware_id: str = ''):
         """
         This method tag hardware ( bare-metals ) from the user tags from the gsheet
@@ -96,5 +102,7 @@ class TagBareMetal(TaggingOperations):
         else:
             hardware_ids = self._classic_operations.get_hardware_ids()
             for hardware_id in hardware_ids:
-                response.append({hardware_id.get('hostname'): self.tag_hardware(hardware_id=hardware_id.get('id'))})
+                response_data = self.tag_hardware(hardware_id=hardware_id.get('id'))
+                if response_data:
+                    response.append({hardware_id.get('hostname'): response_data})
         return response
